@@ -1,7 +1,8 @@
+"""Showtime Types Module"""
+
 from enum import Enum
 from typing import NamedTuple
 from typing_extensions import TypedDict
-from collections import namedtuple
 
 ShowId = int
 EpisodeId = int
@@ -16,6 +17,7 @@ class TVMazeShow(NamedTuple):
     status: str
     url: str
 
+
 class TVMazeEpisode(NamedTuple):
     """API Episode result"""
     id: int
